# HG changeset patch
# User Aarthi Thirumalai<aar...@multicorewareinc.com>
# Date 1403716778 -19800
#      Wed Jun 25 22:49:38 2014 +0530
# Node ID dd4ca794e746ecb04eb76dfdb32e9ef16f642e77
# Parent  0995efabd44470c1192994e1aceeb40ae606467f
rc: rename texBits to coeffBits in RateControlEntry structure to maintain 
uniformity.

diff -r 0995efabd444 -r dd4ca794e746 source/encoder/ratecontrol.h
--- a/source/encoder/ratecontrol.h      Wed Jun 25 22:48:55 2014 +0530
+++ b/source/encoder/ratecontrol.h      Wed Jun 25 22:49:38 2014 +0530
@@ -53,7 +53,7 @@
 
 struct RateControlEntry
 {
-    int64_t texBits;  /* Required in 2-pass rate control */
+    int64_t coeffBits;  /* Required in 2-pass rate control */
     int64_t lastSatd; /* Contains the picture cost of the previous frame, 
required for resetAbr and VBV */
 
     int sliceType;
_______________________________________________
x265-devel mailing list
x265-devel@videolan.org
https://mailman.videolan.org/listinfo/x265-devel

Reply via email to
diff -r 0995efabd444 -r dd4ca794e746 source/encoder/ratecontrol.cpp
--- a/source/encoder/ratecontrol.cpp    Wed Jun 25 22:48:55 2014 +0530
+++ b/source/encoder/ratecontrol.cpp    Wed Jun 25 22:49:38 2014 +0530
@@ -692,8 +692,8 @@
         m_shortTermCplxCount *= 0.5;
         m_shortTermCplxSum += m_currentSatd / (CLIP_DURATION(m_frameDuration) 
/ BASE_FRAME_DURATION);
         m_shortTermCplxCount++;
-        /* texBits to be used in 2-pass */
-        rce->texBits = m_currentSatd;
+        /* coeffBits to be used in 2-pass */
+        rce->coeffBits = m_currentSatd;
         rce->blurredComplexity = m_shortTermCplxSum / m_shortTermCplxCount;
         rce->mvBits = 0;
         rce->sliceType = m_sliceType;